**********************************************************************
* Katrin Auspurg & Thomas Hinz (in cooperation with Carsten Sauer)
* Accompanying material for: Factorial Survey Experiments.
* SAGE,  Series: Quantitative Applications in the Social Sciences No. 175, 
* Thousand Oaks, CA: SAGE
* 
* // 5.1 DATA PREPARATION
*************************************************************************


**** Two files will be merged: population_sample.dta (N=250, first 250 cases from the Justice of Earnings Study 2008, Konstanz 
**** and population_sample_setup.dta (with the experimental set-up)

// #0
// program setup

clear all
macro drop _all
version 12.1
set more off

//  #1
// load dataset with respondent data, reshape and merge

**** define your working volume with the cd (change directory) command
**** this is the directory where you store the data on your system, PC, laptop, etc.

cd "C:\Users\katrin.auspurg\Documents\Sage textbook\Website\5_material\Preparation\"


use 5_population_sample.dta, clear
reshape long vig_eval, i(id_resp) j(vignr)
merge 1:1 id_resp vignr using 5_population_sample_setup.dta
drop if _merge == 2
drop _merge


// #2 
// data preparation

**** Create the MPS prestige score out of the vignette person's job according to a scale handbook

gen prestige = 20 if job ==1
replace prestige = 36.6 if job ==2
replace prestige = 55.7 if job ==3
replace prestige = 69.9 if job ==4
replace prestige = 77.9 if job ==5
replace prestige = 91.5 if job ==6
replace prestige = 119.9 if job ==7
replace prestige = 126.2 if job ==8
replace prestige = 144.5 if job ==9
replace prestige = 170.9 if job ==10
label var prestige "VIGN: occupational prestige of vignette person's job (MPS)"

**** Some simple recoding in order to get dummy variables, logged variables etc.

gen educ_high = 0
replace educ_high = 1 if v3 >= 5
lab var educ_high "RESP: indicator of university degree (0/1)"

gen log_income = ln(income)
label var log_income "VIGN: logged monthly gross income of vignette person in EUR" 

gen vsex_f = sex -1
label var vsex_f "VIGN: indicator of a female vignette person (0/1)"
label def l1 0 "male" 1 "female"
label val vsex_f l1

gen degree2 = degree == 2
label var degree2 "VIGN: indicator of vocational training degree of vignette person (0/1)"

gen degree3 = degree == 3
label var degree3 "VIGN: indicator of university degree of vignette person(0/1)"

gen experience_d = experience - 1
label var experience_d "VIGN: indicator of a lot of experience of vignette person (0/1)"

gen tenure_d = tenure - 1
label var tenure_d "VIGN: indicator of long tenure of vignette person(0/1)"

**** Generation of interaction terms 

gen vsex_fXeduc_high = vsex_f * educ_high
lab var vsex_fXeduc_high "INT: RESP educ_high with VIGN female"

gen degree2Xeduc_high = degree2 * educ_high  
lab var degree2Xeduc_high ""

gen degree3Xeduc_high = degree3 * educ_high
lab var degree3Xeduc_high "INT: RESP educ_high with VIGN vocational training degree"

gen childrenXeduc_high = children * educ_high
lab var childrenXeduc_high "INT: RESP educ_high with VIGN number of children"

gen prestigeXeduc_high = prestige * educ_high 
lab var prestigeXeduc_high "INT: RESP educ_high with VIGN occupational prestige"

gen experienceXeduc_high = experience * educ_high
lab var experienceXeduc_high "INT: RESP educ_high with VIGN experience"

gen tenureXeduc_high = tenure * educ_high 
lab var tenureXeduc_high "INT: RESP educ_high with VIGN tenure"

gen log_incomeXeduc_high = log_income * educ_high 
lab var log_incomeXeduc_high "INT: RESP educ_high with VIGN log_income"

sum income
gen mean_income = r(mean)
lab var mean_income "VIG: mean income of vignette person"


// #3 
// save data 

saveold 5_data.dta, replace 

