**********************************************************************
* Katrin Auspurg & Thomas Hinz (in cooperation with Carsten Sauer)
* Accompanying material for: Factorial Survey Experiments.
* SAGE,  Series: Quantitative Applications in the Social Sciences No. 175, 
* Thousand Oaks, CA: SAGE
* 
* // 5.2 DATA ANALYSES (REGRESSIONS ETC.)
*************************************************************************

// #0
// program setup (only necessary if you did not run the preparation.do in advance)

clear all
macro drop _all
version 12.1
set more off


//  #1
// load dataset 

**** define your working volume with the cd (change directory) command
****(only necessary if you did not run the preparation.do in advance)

cd "C:\Users\katrin.auspurg\Documents\Sage textbook\Website\5_material\"


**** Open data data.dta (data is stored in the long format, stata12)
**** All variables and interaction variables were built in advance from original variables by simple transformations
use 5_data.dta


//  #2
// descriptive analyses

**** Reproduce the frequency distribution (page 94)
hist vig_eval, dis


//  #3
// regression analyses

**** Table 5_1 OLS (page 96)
reg vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income 

**** Table 5_1 OLS with cluster robust standard errors (page 96)
reg vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income, cluster (id_resp)

**** Table 5_1 Random intercept (page 96)
xtreg vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income,  i(id_resp) re

**** OLS regression with all main effects and interactions (to prepare Chow-Test, reported on page 97) 
reg vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income ///
vsex_fXeduc_high degree2Xeduc_high degree3Xeduc_high childrenXeduc_high prestigeXeduc_high experienceXeduc_high tenureXeduc_high log_incomeXeduc_high educ_high, cluster(id_resp)

**** Chow-Test (reported on page 97)
test vsex_fXeduc_high degree2Xeduc_high degree3Xeduc_high childrenXeduc_high prestigeXeduc_high experienceXeduc_high tenureXeduc_high log_incomeXeduc_high educ_high

**** Random slope models (results reported on page 97)
xtmixed vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income || id_resp: vsex_f , cov(unstruct) 
xtmixed vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income || id_resp: age , cov(unstruct) 
xtmixed vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income || id_resp: degree2 , cov(unstruct) 
xtmixed vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income || id_resp: degree3 , cov(unstruct) 
xtmixed vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income || id_resp: children , cov(unstruct) 
xtmixed vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income || id_resp: experience_d , cov(unstruct) 
xtmixed vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income || id_resp: tenure_d , cov(unstruct) 
xtmixed vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income || id_resp: log_income , cov(unstruct) 

**** Table 5_2 Random intercept with L2 education (page 98)
xtreg vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income educ_high, i(id_resp) re

**** Table 5_2 Random intercept for education "low" (page 98)
xtreg vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income if educ_high==0, i(id_resp) re
 
**** Table 5_2 Random intercept for education "high" (page 98)
xtreg vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income if educ_high==1, i(id_resp) re

**** Table 5_2 Random intercept with cross level interactions (page 98)
xtreg vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income educ_high degree2Xeduc_high degree3Xeduc_high , i(id_resp) re


//  #4
// further analyses (cross elasticities, WTP)

**** Relative effect sizes and cross-elasticity (page 100)
reg vig_eval vsex_f age degree2 degree3 children experience_d tenure_d prestige log_income , cluster(id_resp)

**** Estimation of JGPG and save coeffcients (page 100)
gen wagegap_p = exp( - (_b[vsex_f] / _b[log_income]))
replace wagegap_p = (wagegap_p -1 ) *100         /*%JGPG  */
gen wagegap =  (mean_income * wagegap_p)/100     /*JGPG in EUR*/
fre wagegap wagegap_p

**** Alternative use of stata ado "wtp" (must be installed, page 101) 
**** Note: with logged variables there is a minor deviance compared to the estimation above
wtp log_income vsex_f


//  #5
// analyses addressing censored responses

**** Table 5_3 RI (see Table 5_1) (page 103)
xtreg vig_eval vsex_f age degree2 degree3 children prestige experience_d tenure_d log_income, i(id_resp) re
**** Table 5_3 Tobit (RI) lower limit (-5) (page 103)
xttobit vig_eval vsex_f age degree2 degree3 children experience_d tenure_d prestige log_income , ll(-5) tobit
**** Table 5_3 Tobit (RI) lower and upper limits (-5 and 5) (page 103)
xttobit vig_eval vsex_f age degree2 degree3 children experience_d tenure_d prestige log_income , ll(-5) ul(5) tobit


//  #6
// exit program

exit
